Increased timeout for rietveld lint calls.

BUG=

Review URL: https://codereview.chromium.org/342543003

git-svn-id: svn://svn.chromium.org/chrome/trunk/tools/depot_tools@279463 0039d316-1c4b-4281-b951-d872f2087c98
diff --git a/tests/gcl_unittest.py b/tests/gcl_unittest.py
index b3dbf53..602bafb 100755
--- a/tests/gcl_unittest.py
+++ b/tests/gcl_unittest.py
@@ -376,7 +376,7 @@
           '--file=descfile'],
         change_info.patch).AndReturn(("1", "2"))
     gcl.os.remove('descfile')
-    change_info.SendToRietveld("/lint/issue%s_%s" % ('1', '2'), timeout=10)
+    change_info.SendToRietveld("/lint/issue%s_%s" % ('1', '2'), timeout=60)
     gcl.os.chdir('somewhere')
     gcl.sys.stdout.write("*** Upload does not submit a try; use gcl try to"
                          " submit a try. ***")
@@ -418,7 +418,7 @@
         ['upload.py', '-y', '--server=https://my_server', "--file=descfile" ],
         change_info.patch).AndReturn(("1", "2"))
     gcl.os.remove('descfile')
-    change_info.SendToRietveld("/lint/issue%s_%s" % ('1', '2'), timeout=10)
+    change_info.SendToRietveld("/lint/issue%s_%s" % ('1', '2'), timeout=60)
     gcl.os.chdir('somewhere')
     gcl.sys.stdout.write("*** Upload does not submit a try; use gcl try to"
                          " submit a try. ***")
diff --git a/gcl.py b/gcl.py
index 1502c06..82aa96a 100755
--- a/gcl.py
+++ b/gcl.py
@@ -403,9 +403,9 @@
     if self.issue and self.patchset:
       try:
         self.SendToRietveld('/lint/issue%s_%s' % (self.issue, self.patchset),
-            timeout=10)
+            timeout=60)
       except ssl.SSLError as e:
         # It takes more than 10 seconds to lint some CLs. Silently ignore
         # the expected timeout.
         if e.message != 'The read operation timed out':
           raise
@@ -403,9 +403,9 @@
       except ssl.SSLError as e:
-        # It takes more than 10 seconds to lint some CLs. Silently ignore
+        # It takes more than 60 seconds to lint some CLs. Silently ignore
         # the expected timeout.
         if e.message != 'The read operation timed out':